#ifndef _MATCH_PARENT_STYLE_H_INCLUDED_
#define _MATCH_PARENT_STYLE_H_INCLUDED_

/*++
/* NAME
/*	match_parent_style 3h
/* SUMMARY
/*	parent domain matching control
/* SYNOPSIS
/*	#include <match_parent_style.h>
/* DESCRIPTION
/* .nf

 /*
  * Utility library.
  */
#include <match_list.h>

 /*
  * External interface.
  */
extern int match_parent_style(const char *);

/* LICENSE
/* .ad
/* .fi
/*	The Secure Mailer license must be distributed with this software.
/* AUTHOR(S)
/*	Wietse Venema
/*	IBM T.J. Watson Research
/*	P.O. Box 704
/*	Yorktown Heights, NY 10598, USA
/*--*/

#endif
